==> haskell-recaptcha-0.1.0.4-368-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-BtDStHlLSNwIOOqug7hBaw
key:                  recaptcha-0.1.0.4-BtDStHlLSNwIOOqug7hBaw
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  2cea6786710b4090f6160ba73cd2bbba
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.6.6/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-BtDStHlLSNwIOOqug7hBaw
depends:
    HTTP-4000.4.1-Ly7mWNR2wStKTaMfBZ435s base-4.18.2.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recaptcha-0.1.0.4-370-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-Giqw7y5EBNv9hchYrP8iVJ
key:                  recaptcha-0.1.0.4-Giqw7y5EBNv9hchYrP8iVJ
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  f802a962dc2e4f15e47aaac0eac7ba2b
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.6.6/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-Giqw7y5EBNv9hchYrP8iVJ
depends:
    HTTP-4000.4.1-9QKOH3moG66E3gEMmY9ujp base-4.18.2.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
